ActiveExecutorContext

Struct ActiveExecutorContext 

pub struct ActiveExecutorContext<E, M: Model<E>> { /* private fields */ }
Context for tick processing where micro-steps can be executed.

Implementations

Source

impl<E, M: Model<E>> ActiveExecutorContext<E, M>

pub fn begin_micro_step( self, model: &M, ) -> MicroStepHandler<ActiveExecutorContext<E, M>>

Initiates micro-step processing.

pub fn end_tick_with_increment_tick(self, model: &M) -> ExecutorContext<E, M>

Ends the current tick and advances to the next tick by incrementing by 1.

pub fn end_tick_with_jump_to_next_tick(self, model: &M) -> ExecutorContext<E, M>

Ends the current tick and jumps to the next tick based on scheduled events or sources. If no further scheduled times are found, defaults to incrementing by 1.

pub fn discard_remain_micro_step( &mut self, model: &M, ) -> (VecDeque<SourceReadyEntry>, VecDeque<Event<E>>)

Discards any remaining micro-steps in the current tick.

Returns

A pair containing the discarded sources and events.