pub struct SourceContext<E, M: Model<E>> { /* private fields */ }Expand description
Context information provided during the source execution phase.
This context provides access to the current simulation time and micro-step status during model execution, as well as functionality for scheduling events.