pub struct EventContext<E, M: Model<E>> { /* private fields */ }Expand description
Holds and manages context information during event processing.
This provides access to the current simulation time, micro-step status, hook management, source handling, and the event scheduler during model execution.
Implementations
Sourceimpl<E, M: Model<E>> EventContext<E, M>
impl<E, M: Model<E>> EventContext<E, M>
Sourcepub fn add_source<S>(&mut self, model: &M, name: &'static str, source: S)where
S: Source<E, M> + 'static,
pub fn add_source<S>(&mut self, model: &M, name: &'static str, source: S)where
S: Source<E, M> + 'static,
Registers a new source and adds it to the event processing loop.
Arguments
model- The model associated with the source.name- A unique identifier for the source.source- The source implementation to register.
Sourcepub fn cancel_scheduled_sources<S, F>(
&mut self,
model: &M,
pred: F,
) -> Vec<(SimTime, SourceReadyEntry)>
pub fn cancel_scheduled_sources<S, F>( &mut self, model: &M, pred: F, ) -> Vec<(SimTime, SourceReadyEntry)>